#! /bin/bash

#
# These should be installed in current directory when installing the rpm
# (the rpm install will place them in /tmp/hpe-atx.install.lic and then
# cd to that directory ro run this script): 
#
#	install_ap.sh		(this script)
#	916_1.0_HPE-ATX_1.0.pd	(ATX AutoPass PD file)
#	libOvLicV5Capi64.so	(AutoPass library)
#
# If run from an rpm install the rpm processing will remove
# /tmp/hpe-atx.install.lic and all it's files before finishing
#
# This script will create all of the required directories and files that
# are needed by AutoPass. Finally the Instant-On Trial license will be
# installed so that the product can immediately be used. Existing AutoPass
# license file (LicFile.txt) will *not* be removed or overwritten.
#
# Note: the rpm file could install all of this for us, but if it did then
# if the user uninstalled the product that would also remove all of the 
# license information (both Instant-On Trial licenses as well as purchased
# licenses). We don't want that to happen. By installing these files in 
# /tmp and creating the AutoPass required directories and files in this
# script an rpm uninstall won't know about the AutoPass directories and
# files and leave them on the system.
#


set_perms()
{
	obj="$1"
	mode="$2"

	chown root  $obj
	chgrp root  $obj
	chmod $mode $obj
}


# We separate the AutoPass Install and Data directories.
# The Data directory contains all the hidden AutoPass Instant-On
# information and we don't want the user to easily see this data,
# remove it, and then get another Instant-On duration.

	AP_INST_DIR="/usr/lib64/hpeovlic-atx"
	AP_DATA_DIR="/usr/lib64/.hpeovlic-atx"

# Name of the AutoPass PD and license files in the AutoPass Install directory

	AP_LIC_FILE="LicFile.txt"


# clean up old stuff if requested (removes existing licenses)

	if [ "$1" == "-clean" ] ; then
		rm -rf $AP_INST_DIR $AP_DATA_DIR
	fi


##################################################################
# Install Directory
##################################################################

# The rpm sets up most of the install directory stuff. However, we
# need to create a license file if one doesn't already exist. We
# don't want rpm to do that for us because we don't want the licenses
# to be removed on an uninstall.

	if [ ! -f $AP_INST_DIR/$AP_LIC_FILE ] ; then
		touch             $AP_INST_DIR/$AP_LIC_FILE
	fi
	set_perms $AP_INST_DIR/$AP_LIC_FILE   "0644"


##################################################################
# Data Directory
#
# Now let's create the Data directory that we don't want removed
# by rpm -e.
##################################################################

# Create new AutoPass Data directories if they don't exist already

	mkdir -p  $AP_DATA_DIR
	mkdir -p  $AP_DATA_DIR/log
	mkdir -p  $AP_DATA_DIR/conf
	

# set directory permissions

	set_perms $AP_DATA_DIR        "0755"
	set_perms $AP_DATA_DIR/log    "0755"
	set_perms $AP_DATA_DIR/conf   "0755"


# Create the AutoPass debug file 

	cp $AP_INST_DIR/conf/OvLicDebug.ini $AP_DATA_DIR/conf

	set_perms $AP_DATA_DIR/conf/OvLicDebug.ini        "0644"


##################################################################
# Install the Instant-On license for ATX
##################################################################

	/usr/bin/hpe-atx --license-instant-on   # -i option

	ret=$?
	if [ $ret -ne 0 ] ; then
		echo "Error: Instant-on License install failed"
		exit 1
	fi

	exit 0

